@@ -4,7 +4,7 @@ from deepforest import main
 from deepforest import get_data
 import os
 import pytest
-import cv2
+import numpy as np
 
 @pytest.fixture()
 def m():
@@ -31,6 +31,19 @@ def test_format_boxes(m):
         assert not target_df.empty
         
 
+def test_plot_predictions(m, tmpdir):
+    ds = m.val_dataloader()
+    batch = next(iter(ds))
+    paths, images, targets = batch
+    for path, image, target in zip(paths, images, targets):
+        target_df = visualize.format_boxes(target, scores=False)
+        target_df["image_path"] = path
+        image = np.array(image)[:,:,::-1]
+        image = visualize.plot_predictions(image, target_df)
+
+        assert image.dtype == "uint8"
+        
+    
 def test_plot_prediction_dataframe(m, tmpdir):
     ds = m.val_dataloader()
     batch = next(iter(ds))
